cli

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateAuthCommand

func CreateAuthCommand(a *auth.Auth) *cobra.Command

CreateAuthCommand creates the auth command and its subcommands

func CreateMediaCommand

func CreateMediaCommand(auth *auth.Auth) *cobra.Command

CreateMediaCommand creates the media command and its subcommands

func CreateRootCommand

func CreateRootCommand(cfg *config.Config, a *auth.Auth) *cobra.Command

CreateRootCommand creates the root command for the xurl CLI

func CreateShortcutCommands

func CreateShortcutCommands(rootCmd *cobra.Command, a *auth.Auth)

func CreateVersionCommand

func CreateVersionCommand() *cobra.Command

CreateVersionCommand creates the version command

func CreateWebhookCommand

func CreateWebhookCommand(authInstance *auth.Auth) *cobra.Command

CreateWebhookCommand creates the webhook command and its subcommands.

func RunPicker

func RunPicker(title string, items []string) (string, error)

RunPicker launches an interactive Bubble Tea list picker and returns the selected item, or an empty string if the user cancelled.

Types

This section is empty.

Jump to