Documentation
¶
Index ¶
Constants ¶
const DefaultRedirectURI = "http://localhost:8080/callback"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// OAuth2 client tokens (may come from env vars or the active app in .xurl)
ClientID string
ClientSecret string
// OAuth2 PKCE flow urls
RedirectURI string
// RedirectURIFromEnv tracks whether REDIRECT_URI came from the environment.
RedirectURIFromEnv bool
AuthURL string
TokenURL string
// API base url
APIBaseURL string
// API user info url
InfoURL string
// AppName is the explicit --app override; empty means "use default".
AppName string
}
Config holds the application configuration
func NewConfigForApp ¶ added in v1.1.0
NewConfigForApp creates a Config for the given app name.
Click to show internal directories.
Click to hide internal directories.